# Responsible AI Model Analysis SDK for Python

### This package has been tested with Python 3.6, 3.7 and 3.8

The Responsible AI Model Analysis SDK enables users to analyze their machine learning models in one API. Users will be able to analyze errors, explain the most important features, compute counterfactuals and run causal analysis using a single API.

Highlights of the package include:

- `explainer.add()` explains the model
- `counterfactuals.add()` computes counterfactuals
- `error_analysis.add()` runs error analysis
- `causal.add()` runs causal analysis

The source code can be found here:
https://github.com/microsoft/responsible-ai-widgets
